@@ -1,6 +1,6 @@
 /* -copyright-
 #-# 
-#-# Copyright (C) 1999-2001  Robin Hogan, 2021-2024 Willem Vermin
+#-# Copyright (C) 1999-2001  Robin Hogan, 2021-2026 Willem Vermin
 #-# 
 #-# This program is free software; you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -20,16 +20,21 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 #include <X11/Intrinsic.h>
+#include <X11/extensions/Xinerama.h>
 #include "transwindow.h"
+#include "windows.h"
 #include "debug.h"
+#include "xdo.h"
+#include "wmctrl.h"
+#include "toon.h"
 
 
 static int setvaria(GtkWidget *widget);
 
+
 /*
  * creates transparent window using gtk3/cairo. 
  * transwindow: (input)  GtkWidget to create transparent window in
- * fullscreen:  (input)  full-screen or not full screen
  * sticky:      (input)  visible on all workspaces or not
  * below:       (input)  1: below all other windows 2: above all other windows 0: no action
  * dock:        (input)  make it a 'dock' window: no decoration and not interfering with xsnow, xpenguins
@@ -41,9 +46,10 @@ static int setvaria(GtkWidget *widget);
  * gdk_window:  (output) GdkWindow created
  * x11_window:  (output) Window X11 window created
  */
-int make_trans_window(GtkWidget *transwindow, int fullscreen, int sticky, int below, int dock,  
-      GdkWindow **gdk_window, Window *x11_window)
+int make_trans_window(Display *display, GtkWidget *transwindow, int xscreen, int sticky, int below, int dock,  
+      GdkWindow **gdk_window, Window *x11_window, int *wantx, int *wanty)
 {
+   P("Entering make_trans_window... wantx: %d wanty: %d\n",*wantx, *wanty);
    if(gdk_window)
       *gdk_window = NULL;
    if(x11_window)
@@ -95,19 +101,48 @@ int make_trans_window(GtkWidget *transwindow, int fullscreen, int sticky, int be
    // Ensure the widget (the window, actually) can take RGBA
    gtk_widget_set_visual(transwindow, gdk_screen_get_rgba_visual(screen));
 
-   // set full screen if so desired:
-   if(fullscreen)
+   int winx, winy; // desired position of window
+   int winw, winh; // desired size of window
+		   // set full screen if so desired:
+   P("xscreen: %d\n",xscreen);
+
+   if(xscreen < 0)
    {
       P("fullscreen\n");
-      XWindowAttributes attr;
-      Display *display = XOpenDisplay(NULL);
-      XGetWindowAttributes(display,DefaultRootWindow(display),&attr);
-      gtk_widget_set_size_request(GTK_WIDGET(transwindow),attr.width,attr.height);
-      XCloseDisplay(display);
+      // fullscreen, but if there is only one screen, maximize in stead of fullscreen
+      winx = 0;
+      winy = 0;
+      //choose a not too small and not too large size for our initial window:
+      gtk_window_set_default_size(GTK_WINDOW(transwindow),100,100);
+      gtk_window_move(GTK_WINDOW(transwindow),40,40);
+      //gtk_widget_show_all(transwindow);
+      int nscreens = xinerama(display, -1, NULL, NULL, NULL, NULL); 
+      P("nscreens: %d\n",nscreens);
+
+      if (nscreens == 1)
+	 // make window maximized and wait until ready:
+	 wait_for_maximized(transwindow);
+      else
+	 // make window full screen and wait until ready:
+	 wait_for_fullscreen(transwindow);
+      gtk_window_get_size(GTK_WINDOW(transwindow),&winw,&winh);
+      P("winw: %d, winh: %d\n",winw,winh);
    }
-   else
+   else  // xscreen >= 0
    {
-      P("NOT fullsscreen\n");
+      P("NOT fullscreen, but xineramascreen %d\n",xscreen);
+      xinerama(display,xscreen,&winx,&winy,&winw,&winh);
+      P("winx: %d, winy: %d, winw: %d, winh: %d\n",winx, winy,winw,winh);
+      //choose a not too small and not too large size for our initial window:
+      gtk_window_set_default_size(GTK_WINDOW(transwindow),100,100);
+
+      // move it to the desired monitor:
+      gtk_window_move(GTK_WINDOW(transwindow),winx,winy);
+
+      // make window maximized and wait until ready:
+      wait_for_maximized(transwindow);
+      gtk_window_get_size(GTK_WINDOW(transwindow),&winw,&winh);
+      P("winw: %d, winh: %d\n",winw,winh);
    }
 
    gtk_widget_show_all(transwindow);
@@ -116,33 +151,49 @@ int make_trans_window(GtkWidget *transwindow, int fullscreen, int sticky, int be
    // so that apps like xsnow will ignore this window:
    if(dock)
       gdk_window_set_type_hint(gdkwin,GDK_WINDOW_TYPE_HINT_DOCK);
+   else
+      gdk_window_set_type_hint(gdkwin,GDK_WINDOW_TYPE_HINT_NORMAL);
+
 
    gdk_window_hide(gdkwin);
-   if(fullscreen)
-      gdk_window_move(gdkwin,0,0);
+
    gdk_window_show(gdkwin);
 
-   if (x11_window)
-      *x11_window = gdk_x11_window_get_xid(gdkwin);
-   if (gdk_window)
-      *gdk_window = gdkwin;
+   if (x11_window || gdk_window)
+   {
+      Window win = gdk_x11_window_get_xid(gdkwin);
+      if(x11_window)
+	 *x11_window = win;
 
-   usleep(200000);  // seems sometimes to be necessary with nvidia
+      P("resize %p: %d %d\n",(void*)*x11_window,winw,winh);
+      //XResizeWindow(display,*x11_window,winw,winh);  // necessary in xmonad, don't know why,  // TODO 
+      //XMoveWindow(display,*x11_window,winx,winy); 
+      //XFlush(display);                               // in combination with this one
 
-   // just to be sure all settings are communicated with the server
-   gtk_widget_hide(transwindow);
-   gtk_widget_show_all(transwindow);
+      if (gdk_window)
+	 *gdk_window = gdkwin;
 
-   // set some things, but note that this has to be repeated in the gkt_main loop.
+      if(wantx)
+	 *wantx = winx;
+      if(wanty)
+	 *wanty = winy;
+      usleep(200000);  // seems sometimes to be necessary with nvidia
 
-   P("explicitly call setvaria\n");
-   setvaria(transwindow);
-   P("end explicit call\n");
-   g_object_steal_data(G_OBJECT(transwindow),"trans_done");
+      // just to be sure all settings are communicated with the server
+      gtk_widget_hide(transwindow);  // TODO
+      gtk_widget_show_all(transwindow);
 
+      // set some things, but note that this has to be repeated in the gkt_main loop.
+
+      P("explicitly call setvaria\n");
+      setvaria(transwindow);
+      P("end explicit call\n");
+      g_object_steal_data(G_OBJECT(transwindow),"trans_done");
+   }
    return TRUE;
 }
 
+
 // for some reason, in some environments the 'below' and 'stick' properties
 // disappear. It works again, if we express our wishes after starting gtk_main
 // and the best place is in the draw event.
@@ -154,12 +205,12 @@ int setvaria(GtkWidget *widget)
    // Use the value of p itself, not what it points to.
    // Following the C standard, we have to use an array to subtract pointers.
    enum {rep = 1,nrep}; // must be >= 0, and is equal to the number of times the settings
-   //                      will be done when called more than once
+			//                      will be done when called more than once
    static char something[nrep];
    char *p = (char *)g_object_get_data(G_OBJECT(widget),"trans_done");
    if (!p)
       p = &something[0];
-   P("setvaria %p %p %d\n",p,&something,(int)(p-&something[0]));
+   P("setvaria %p %p %d\n",p,(void *)&something,(int)(p-&something[0]));
    if (p - &something[0] >=  rep)
    {
       return FALSE;
@@ -171,6 +222,7 @@ int setvaria(GtkWidget *widget)
 
 
    GdkWindow *gdk_window1 = gtk_widget_get_window(widget);
+   P("gdkwin:");//printgdkwindowattrs(gdk_window1);
    const int Usepassthru = 0;
    if(Usepassthru)
       gdk_window_set_pass_through(gdk_window1,TRUE); // does not work as expected
@@ -182,6 +234,17 @@ int setvaria(GtkWidget *widget)
    }
    P("setvaria %d widget: %p gdkwin: %p passthru: %d\n",counter++,(void *)widget,(void *)gdk_window1,gdk_window_get_pass_through(gdk_window1));
 
+   gdk_window_set_skip_pager_hint ( gdk_window1, TRUE);
+   gdk_window_set_skip_taskbar_hint ( gdk_window1, TRUE);
+   if(toon_monitor >= 0)
+   {
+      gdk_window_fullscreen_on_monitor(gdk_window1,toon_monitor);
+      gdk_window_unfullscreen(gdk_window1);
+      gdk_window_maximize(gdk_window1);
+   }
+
+   P("gtkwin:");//printgtkwindowattrs(GTK_WINDOW(widget));
+   P("gdkwin:");//printgdkwindowattrs(gdk_window1);
 
    if(!g_object_get_data(G_OBJECT(widget),"trans_nobelow"))
    {
