@@ -1,6 +1,6 @@
 /* -copyright-
 #-# 
-#-# Copyright (C) 1999-2001  Robin Hogan, 2021-2024 Willem Vermin
+#-# Copyright (C) 1999-2001  Robin Hogan, 2021-2026 Willem Vermin
 #-# 
 #-# This program is free software; you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -22,7 +22,9 @@
 
 #pragma once
 
-extern int make_trans_window(GtkWidget *Transwindow, int Fullscreen, int sticky, int below, int dock,
-      GdkWindow **gdk_window, Window *x11_window);
+extern int make_trans_window(Display *display, GtkWidget *transwindow, 
+      int xscreen, int sticky, int below, int dock,  
+      GdkWindow **gdk_window, Window *x11_window, int *wantx, int *wanty);
+
 void setbelow(GtkWindow *w);
 void setabove(GtkWindow *w);
