@@ -1,6 +1,6 @@
 /* -copyright-
 #-# 
-#-# Copyright (C) 1999-2001  Robin Hogan, 2021-2024 Willem Vermin
+#-# Copyright (C) 1999-2001  Robin Hogan, 2021-2026 Willem Vermin
 #-# 
 #-# This program is free software; you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@
 #include "debug.h"
 #include "toon.h"
 
+#define ignore_atom "IGNORE_ME"
 int GetWindows(WinInfo **windows, int *nwin)
 {
    Atom type;
@@ -59,6 +60,7 @@ int GetWindows(WinInfo **windows, int *nwin)
    static Atom atom_win_client_list;
    static Atom atom_win_workspace;
    static Atom atom_wm_state;
+   static Atom atom_ignore;
 
    static Window Rootwindow;
 
@@ -78,6 +80,7 @@ int GetWindows(WinInfo **windows, int *nwin)
       atom_win_client_list      = XInternAtom(getdisplay, "_WIN_CLIENT_LIST"     ,False);
       atom_win_workspace        = XInternAtom(getdisplay, "_WIN_WORKSPACE"       ,False);
       atom_wm_state             = XInternAtom(getdisplay, "WM_STATE"             ,False);
+      atom_ignore               = XInternAtom(getdisplay, ignore_atom            ,False);
 
       Rootwindow                = DefaultRootWindow(getdisplay);
    }
@@ -111,10 +114,13 @@ int GetWindows(WinInfo **windows, int *nwin)
 	 XFree(children);
 	 children = NULL;
       }
-      Window dummy;
-      unsigned int n;
-      XQueryTree(getdisplay,DefaultRootWindow(getdisplay),&dummy,&dummy,&children,&n);
-      nchildren = n;
+
+      {
+	 Window dummy;
+	 unsigned int n;
+	 XQueryTree(getdisplay,DefaultRootWindow(getdisplay),&dummy,&dummy,&children,&n);
+	 nchildren = n;
+      }
    }
    P("----------------------------------------- nchildren: %ld\n",nchildren);
    (*nwin) = nchildren;
@@ -122,6 +128,8 @@ int GetWindows(WinInfo **windows, int *nwin)
    if(nchildren>0)
       (*windows) = (WinInfo *)malloc(nchildren*sizeof(WinInfo));
    WinInfo *w = (*windows);
+   if(w)
+      memset(w,0,sizeof(WinInfo));
    int k = 0;
 
    // and yet another check if window is hidden (needed e.g. in KDE/plasma after 'hide all windows')
@@ -137,7 +145,7 @@ int GetWindows(WinInfo **windows, int *nwin)
 	       AnyPropertyType, &type, &format, &nitems, &b, &properties);
 	 if(format == 32 && nitems >=1)
 	 {
-	    if(*(long*)(void*) properties == 1)
+	    if(*(long*) (void*)properties == 1)
 	       globalhidden = 1;
 	    P("hidden3 hidden:%d\n",globalhidden);
 	 }
@@ -145,9 +153,13 @@ int GetWindows(WinInfo **windows, int *nwin)
       }
    }
 
-   unsigned long i;
-   for (i=0; i<nchildren; i++)
+   for (unsigned long i=0; i<nchildren; i++)
    {
+      // loop over all children of root
+      // all children are included in windows
+      // except those with depth=0
+      // sticky, dock, hidden and ignore are set as appropriate
+
       int x0,y0,xr,yr;
       unsigned int depth;
 
@@ -181,6 +193,7 @@ int GetWindows(WinInfo **windows, int *nwin)
 	    AnyPropertyType, &type, &format, &nitems, &b, &properties);
       if(type != XA_CARDINAL)
       {
+	 // workspace number
 	 if(properties) XFree(properties);
 	 properties = NULL;
 	 XGetWindowProperty(getdisplay, w->id, atom_win_workspace, 0, 1, False, 
@@ -188,11 +201,23 @@ int GetWindows(WinInfo **windows, int *nwin)
       }
       if(properties)
       {
-	 w->ws = *(long*) (void*) properties;
+	 w->ws = *(long*) (void*)properties;
 	 if(properties) XFree(properties);
       }
       else
 	 w->ws = 0;
+
+      // to be ignored by Atom ignore_atom?
+      XGetWindowProperty(getdisplay, w->id, atom_ignore, 0, (~0L), False,
+	    AnyPropertyType, &type, &format, &nitems, &b, &properties);
+      if(type == None)
+	 w->ignore = 0;
+      else
+	 w->ignore = 1;
+      if(properties)
+	 XFree(properties);
+      P("ignore #%lx %d %d\n",w->id,w->ignore,rc);
+
       // maybe this window is sticky:
       w->sticky = 0;
       properties = NULL;
@@ -201,8 +226,7 @@ int GetWindows(WinInfo **windows, int *nwin)
 	    AnyPropertyType, &type, &format, &nitems, &b, &properties);
       if (type == XA_ATOM)
       {
-	 int i;
-	 for(i=0; (unsigned long)i<nitems; i++)
+	 for(int i=0; (unsigned long)i<nitems; i++)
 	 {
 	    char *s = NULL;
 	    s = XGetAtomName(getdisplay,((Atom*)(void*)properties)[i]);
@@ -229,8 +253,7 @@ int GetWindows(WinInfo **windows, int *nwin)
 	    AnyPropertyType, &type, &format, &nitems, &b, &properties);
       if(format == 32)
       {
-	 int i;
-	 for(i=0; (unsigned long)i<nitems; i++)
+	 for(int i=0; (unsigned long)i<nitems; i++)
 	 {
 	    char *s = NULL;
 	    s = XGetAtomName(getdisplay,((Atom*)(void*)properties)[i]);
@@ -265,8 +288,7 @@ int GetWindows(WinInfo **windows, int *nwin)
 	       AnyPropertyType, &type, &format, &nitems, &b, &properties);
 	 if(format == 32)
 	 {
-	    unsigned long i;
-	    for (i=0; i<nitems; i++)
+	    for (unsigned long i=0; i<nitems; i++)
 	    {
 	       char *s = NULL;
 	       s = XGetAtomName(getdisplay,((Atom*)(void*)properties)[i]);
@@ -364,10 +386,46 @@ int GetWindows(WinInfo **windows, int *nwin)
       k++;
    }
    if(properties) XFree(properties);
+   if(children) XFree(children);
    (*nwin) = k;
-   //P("%d\n",counter++);printwindows(getdisplay,*windows,*nwin);
+   P("%d\n",counter++);//printwindows(getdisplay,*windows,*nwin);
    return 1;
 }
 
+void GetAbsoluteCoordinates(Display *display, Window win, int *x, int *y, int *w, int *h)
+{
+   Window child;
+   XWindowAttributes xwa;
+   int xx,yy;
+   XTranslateCoordinates( display, win, DefaultRootWindow(display), 0, 0, &xx, &yy, &child );
+   XGetWindowAttributes( display, win, &xwa );
+   P( "window: %p x: %d y: %d w: %d h: %d\n", (void*)win, xx - xwa.x, yy - xwa.y, xwa.width, xwa.height );
+   if(x)
+      *x = xx - xwa.x;
+   if(y)
+      *y = yy - xwa.y;
+   if(w)
+      *w = xwa.width;
+   if(h)
+      *h = xwa.height;
+}
+void printwindows(Display *dpy,WinInfo *windows, int nwin)
+{
+   WinInfo *w = windows;
+   for (int i=0; i<nwin; i++)
+   {
+      char *name;
+      XFetchName(dpy, w->id, &name);
+      if (!name)
+	 name = strdup("No name");
+      if (strlen(name)>20)
+	 name[20] = '\0';
+      printf("id:%#10lx ws:%3d x:%6d y:%6d xa:%6d ya:%6d w:%6d h:%6d sticky:%d dock:%d hidden:%d name:%s\n",
+	    w->id,w->ws,w->x,w->y,w->xa,w->ya,w->w,w->h,w->sticky,w->dock,w->hidden,name);
+      XFree(name);
+      w++;
+   }
+   return;
+}
 
 
