@@ -1,6 +1,6 @@
 /* -copyright-
 #-# 
-#-# Copyright (C) 1999-2001  Robin Hogan, 2021-2024 Willem Vermin
+#-# Copyright (C) 1999-2001  Robin Hogan, 2021-2026 Willem Vermin
 #-# 
 #-# This program is free software; you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -35,8 +35,12 @@ typedef struct _WinInfo
    unsigned int sticky:  1; // is visible on all workspaces
    unsigned int dock  :  1; // is a "dock" (panel)
    unsigned int hidden:  1; // is hidden (iconified)
+   unsigned int ignore:  1; // should be ignored (maybe a xpenguins transparent window)
 #endif
 } WinInfo;
 
 extern int          GetWindows(WinInfo **w, int *nw);
+extern void GetAbsoluteCoordinates(Display *display, Window win, int *x, int *y, int *w, int *h);
+extern void printwindows(Display *dpy, WinInfo *windows, int nwin);
+
 
