@@ -1,7 +1,7 @@
 /* xpenguins_core.c - provides the core functionality of xpenguins
  * -copyright-
 #-# 
-#-# Copyright (C) 1999-2001  Robin Hogan, 2021-2024 Willem Vermin
+#-# Copyright (C) 1999-2001  Robin Hogan, 2021-2026 Willem Vermin
 #-# 
 #-# This program is free software; you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -152,7 +152,7 @@ char *xpenguins_start(char *display_name)
       unsigned long configure_mask = TOON_SIDEBOTTOMBLOCK;
 
       /* reset random-number generator */
-      srand(time((long *) NULL));  // superfluous
+      srand(time((time_t *) NULL));  // superfluous
       if (!ToonOpenDisplay(display_name)) {
 	 return toon_error_message;
       }
@@ -293,21 +293,6 @@ void xpenguins_set_number(int n)
 /* Don't advance penguins, but check if they have been uncovered by 
  * moving windows and need to be redrawn. */
 /* not used */
-#if 0
-void xpenguins_pause_frame()
-{
-   if (!xpenguins_active) {
-      return;
-   }
-
-   /* check if windows have moved */
-   if ( ToonWindowsMoved() ) {
-      ToonErase(penguin, penguin_number);
-      ToonDraw(penguin, penguin_number);
-      ToonLocateWindows();
-   }
-}
-#endif
 // used during examining and debugging:
 float termv(int i)
 {
